<template>
  <div style="display: flex; flex-direction: column; align-items: center;">
  <div>开诊时间：{{ openingPeriod }}  开诊标记：{{ openingFlag }}</div>
  <div style="display: flex; flex-wrap: wrap; justify-content: center; margin-bottom: 20px">
    <div class=wrap v-for="(value, key) in bedMap" :key="key">
      <RoomStatus :title="key" :bedList="value"  @refresh="getList"/>
    </div>
  </div>
  <div>
    <el-button @click="startBiz" > 手动开诊 </el-button>
    <el-button @click="resetRoom" > 重置诊室 </el-button>
    <el-button @click="resetSchedule" > 重置定时任务 </el-button>
    <el-button @click="refresh" > 刷新 </el-button>
  </div>
  </div>
</template>

<script setup lang="ts">
import {RoomStatus} from "@/components/RoomStatus"
import { RoomApi, RoomVO } from '@/api/ecg/room'
import { QueueApi } from '@/api/ecg/queue'
import { getConfigKey } from '@/api/infra/config'

defineOptions({ name: 'RoomStatusSetting' })

const bedMap = ref() // 列表的数据

const openingPeriod = ref<string>('')
const openingFlag = ref<number>(0)

const getOpeningPeriod = async () => {
  const data = await getConfigKey('ecg.openingtime')
  openingPeriod.value = data
}

const getOpeningFlag = async () => {
  const data = await RoomApi.getOpeningFlag()
  openingFlag.value = data
}

/** 查询列表 */
const getList = async () => {
    const data = await RoomApi.getAllBedMap()
    bedMap.value = data as Map<String, RoomVO[]>
}

const startBiz = async () => {
    await QueueApi.startBiz();
}

const resetRoom = async () => {
    await RoomApi.resetRoom();
    getList()
}

const resetSchedule = async () => {
    await QueueApi.resetSchedule();
}

const refresh = () => {
  getList()
  getOpeningPeriod()
  getOpeningFlag()
}

/** 初始化 **/
onMounted(() => {
  getList()
  getOpeningPeriod()
  getOpeningFlag()
})

</script>

<style scoped lang="scss">
.wrap {
  margin-right: 20px;
}
</style>
